@@ -1,5 +1,5 @@
 ;;; jde-db.el -- Debugger mode for jdb.
-;; $Revision: 1.30 $ $Date: 1998/06/30 04:03:19 $ 
+;; $Revision: 1.33 $ $Date: 1998/11/22 18:18:36 $ 
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
@@ -112,7 +112,7 @@ the `jde-db-option' variable group."
 
 
 (defgroup jde-db-options nil
-  "JDE Interpreter Options"
+  "JDE Debugger Options"
   :group 'jde
   :prefix "jde-run-option-")
 
@@ -517,7 +517,7 @@ breakpoint message."
 
 	  ;; (message "jde-db package: %s" jde-db-last-package)
 
-	  (setq output (concat premarker "Stopped at line " line-no " in "
+	  (setq output (concat premarker "Stopped at line " (int-to-string line-no) " in "
 			       class ".java"))
 
 	  ;; Set the accumulator to the remaining text.
@@ -700,7 +700,7 @@ and create such a submap in that new map."
 	  (setq subst (gud-read-address)))
 	 ((eq key ?p)
 	  (setq subst (if arg (int-to-string arg) ""))))
-	(setq result (concat result group1 subst))))
+	(setq result (concat result group1 (if (integerp subst) (int-to-string subst) subst)))))
     ;; There might be text left in STR when the loop ends.
     (concat result str)))
 
@@ -763,7 +763,11 @@ we're in the jdb buffer)."
 	'(jde-db-interactive-app-arg-history . 1)))))
 
 (defun jde-db-init(app-class marker-filter find-file)
-  (let ((debug-buf-name (concat "*debug" app-class "*")))
+  (let ((debug-buf-name (concat "*debug" app-class "*"))
+	(source-directory default-directory)
+	(working-directory (if (string= jde-run-working-directory "")
+			       default-directory
+			     jde-run-working-directory)))
     (if (not (comint-check-proc debug-buf-name))
 	(let* ((debug-buffer (get-buffer-create debug-buf-name))
 	       (program (if (string= (cdr jde-db-debugger) "Executable")
@@ -789,11 +793,13 @@ we're in the jdb buffer)."
 	  (save-excursion
 	    (set-buffer debug-buffer)
 	    (erase-buffer)
-	    (insert (concat "cd " default-directory "\n"))
+	    (cd working-directory)
+	    (insert (concat "cd " working-directory "\n"))
 	    (insert command-string)
 	    (comint-mode))
 	  (comint-exec debug-buffer app-class program nil prog-args)
 	  (pop-to-buffer debug-buffer)
+	  (cd source-directory)
 	  (gud-mode)
 	  (make-local-variable 'gud-marker-filter)
 	  (setq gud-marker-filter marker-filter)
@@ -855,7 +861,9 @@ CLASS is the name of the class you are debugging."
   (jde-db-def gud-print  "print %e"       "\C-p" "Print object.")
   (local-set-key [menu-bar debug up]   '("Up Stack" . gud-up))
   (local-set-key [menu-bar debug down] '("Down Stack" . gud-down))
+  (make-local-variable 'comint-prompt-regexp)
   (setq comint-prompt-regexp "\\(^> *\\)\\|\\(^.*\\[[0-9]*\\] *\\)")
+  (make-local-variable 'paragraph-start)
   (setq paragraph-start comint-prompt-regexp)
   (run-hooks 'jde-db-mode-hook)
   )
@@ -881,7 +889,7 @@ paths must end in a slash."
  (interactive
   "sEnter source paths: ")
  (let ((m 0)
-       (n (string-match path-separator paths)))
+       (n (string-match jde-classpath-separator paths)))
    (setq jde-db-source-directories (list))
    (while n
      (let ((path (check-source-path (substring paths m n))))
@@ -889,7 +897,7 @@ paths must end in a slash."
 	   (setq jde-db-source-directories
 		 (cons path jde-db-source-directories)))
        (setq m (+ n 1))
-       (setq n (string-match path-separator paths m))))
+       (setq n (string-match jde-classpath-separator paths m))))
    (setq n (length paths))
    (if (and (> n 0) (< m n))
        (let ((path (check-source-path (substring paths m n))))
@@ -904,6 +912,15 @@ paths must end in a slash."
 
 ;; Change History
 ;; $Log: jde-db.el $
+;; Revision 1.33  1998/11/22 18:18:36  paulk
+;; Made comint-prompt-regexp and  paragraph-start local variables.
+;;
+;; Revision 1.32  1998/11/04 02:59:09  paulk
+;; Corrected verbiage in Jde Debugger Options description.
+;;
+;; Revision 1.31  1998/09/12 00:05:57  paulk
+;; Debugger now runs application from directory specified by jde-run-working-directory.
+;;
 ;; Revision 1.30  1998/06/30 04:03:19  paulk
 ;; Added variables `jde-db-read-vm-args' and `jde-db-read-app-args'. The use of
 ;; these variables is the same as the corresponding jde-run variables.
@@ -1032,4 +1049,4 @@ paths must end in a slash."
 ;; Initial revision
 ;;
 
-;;; end of jde-db.el
\ No newline at end of file
+;;; end of jde-db.el
